[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

GRIP Client
===========

__gripql__ is a python library for interacting with a GRIP server.

### Install

Available on [PyPI](https://pypi.org/project/gripql/).

```
pip install gripql
```

Or install the latest development version:

```
pip install "git+https://github.com/bmeg/grip.git#subdirectory=gripql/python"
```

### Getting Started

Check out the getting started guide [here](https://bmeg.github.io/grip/docs/queries/getting_started/).
